REST-Device Service
=============

A RESTful service for one physical device or a virtual device in the xWoT Meta-Model.

Setup
-----

- Install Python
- Run `setup.sh` (Linux, OS X, Cygwin) or `setup.bat` (Windows)
- Run `xwot/bin/python/rest-server.py` to start the server (on Windows use `xwot\Scripts\python rest-server.py` instead)
- Open `http://localhost:9000` on your web browser to run the client

